{% extends "admin/base_site.html" %}
{% load i18n admin_static admin_modify %}
{% load url from compat %}
{% load admin_urls %}

{% block extrahead %}{{ block.super }}
{% url 'admin:jsi18n' as jsi18nurl %}
<script type="text/javascript" src="{{ jsi18nurl|default:"../../../jsi18n/" }}"></script>
{{ media }}
{% endblock %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />{% endblock %}

{% block coltype %}{% if ordered_objects %}colMS{% else %}colM{% endif %}{% endblock %}

{% block bodyclass %}{{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:index' %}redis_admin/manage/">Manage</a>
</div>
{% endblock %}
{% endif %}

{% block content %}
<div id="content-main">
    <div>
        {% if errors %}
        <p class="errornote">
            {% blocktrans count counter=errors|length %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
        </p>
        {{ adminform.form.non_field_errors }}
        {% endif %}
        <fieldset class="module aligned">
            <div class="form-row">
                <div>
                    <label for="id_key" class="required">Key</label>
                    <p>{{ key }}</p>
                </div>
            </div>
            <div class="form-row">
                <div>
                    <label for="id_value" class="required">Value</label>
                    <textarea id="id_value" rows="10" cols="40" name="value" class="vLargeTextField">{{ value }}</textarea>
                </div>
            </div>
        </fieldset>
        <div class="submit-row">
            <p class="deletelink-box"><a href="delete/" class="deletelink">Delete</a></p>
        </div>
    </div>
</div>
{% endblock %}
