{% extends "admin/base_site.html" %}
{% load i18n admin_static admin_modify %}
{% load url from compat %}
{% load admin_urls %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
    &rsaquo; <a href="{% url 'admin:index' %}redis_admin/manage/">Manage</a> &rsaquo;
    {% trans 'Delete' %}
</div>
{% endblock %}
{% endif %}

{% block content %}
    <p>Are you sure you want to delete the key "{{ key }}"?</p>
    <ul><li>Key: <a href="{% url 'admin:index' %}redis_admin/manage/{{ key }}">{{ key }}</a></li></ul>
    <form action="" method="post">{% csrf_token %}
    <div>
    <input type="hidden" name="post" value="yes" />
    <input type="submit" value="{% trans "Yes, I'm sure" %}" />
    </div>
    </form>
{% endblock %}
